CompneyActions class

Constructors

CompneyActions(RawMap data)

Properties

disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableCompeny() Future<FirestoreErrors?>
enableCompeny() Future<FirestoreErrors?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetData() Future<FirestoreErrors?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited