CompneyDoc class

Constructors

CompneyDoc.fromJson(RawMap _rawData)

Properties

action CompneyActions
no setter
buyers Iterable<BuyerInfo>
no setter
hashCode int
The hash code for this object.
no setterinherited
liveRefresh int
no setter
name String
no setter
owner OwnerInfo
no setter
reportAvalable Set<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seller Iterable<SellerInfo>
no setter
workers Iterable<WorkerInfo>
no setter

Methods

getBuyer(String buyerNumber) BuyerInfo
getSeller(int sellerID) SellerInfo
getUser(String userNumber) UserInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inUse CompneyDoc?
no setter