CompneyUserInfo class abstract

Mixed-in types
Implementers

Constructors

CompneyUserInfo(String name, String phoneNumber, bool _isNew)
const

Properties

fieldPath String
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
final
phoneNumber String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

makeChanges({String? newName}) Future<FirestoreErrors?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() Future<FirestoreErrors?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited