OwnerInfo class
- Mixed-in types
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- phoneNumber → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userStatus → UserStatus
-
final
Methods
-
makeChanges(
{String? newName, String? newPhoneNumber}) → Future< FirestoreErrors?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited