WorkerInfo class
- Inheritance
-
- Object
- CompneyUserInfo
- WorkerInfo
Constructors
- WorkerInfo({required String name, required String phoneNumber})
Properties
- fieldPath → String
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- phoneNumber → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userStatus → UserStatus
-
final
Methods
-
makeChanges(
{String? newName}) → Future< FirestoreErrors?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → Future< FirestoreErrors?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited