ConfigDoc class
Constructors
- ConfigDoc.fromJson(RawMap _rawData)
Properties
-
b2b
→ Iterable<
CompneyInfo> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maintenance → Maintenance?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCompney(
String? id) → CompneyInfo? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited