BuyInPaymentEntry class

Inheritance
Mixed-in types

Constructors

BuyInPaymentEntry({required int sellerID, required int amount})

Properties

amount → IntMoney
no setteroverride
belongToDate → DateTimeString
no setterinherited
buyIn BuyIn
final
creator String
finalinherited
dueBoxes Null
final
entryType EntryType
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
isEditable bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellerID int
no setteroverride
sellOut Null
final
timeStamp → DateTimeString
finalinherited

Methods

addEntryToDoc(BuildContext context) Future<FirestoreErrors?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromDoc() Future<FirestoreErrors?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited