Entry class abstract

Implementers

Constructors

Entry({required EntryType entryType})

Properties

belongToDate → DateTimeString
no setter
buyIn BuyIn?
no setter
creator String
final
dueBoxes DueBoxes?
no setter
entryType EntryType
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
isEditable bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellOut SellOut?
no setter
timeStamp → DateTimeString
final

Methods

addEntryToDoc(BuildContext context) Future<FirestoreErrors?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromDoc() Future<FirestoreErrors?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited