ItemQun class

Implementers

Constructors

ItemQun(int id, int quntity, int pack)

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
final
isInv bool
final
pack → IntQuntity
final
pckPerBox → IntQuntity
no setter
quntity → IntQuntity
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
packString() String
quntityString() String
toString({bool lead = true}) String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator unary-() ItemQun