ReturnBoxesEntry class

Inheritance
Mixed-in types

Constructors

ReturnBoxesEntry({required String buyerNumber, required int boxes})

Properties

belongToDate → DateTimeString
no setterinherited
boxes → IntQuntity
no setteroverride
buyerNumber String
no setteroverride
buyIn Null
final
creator String
finalinherited
dueBoxes DueBoxes
final
entryType EntryType
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
finalinherited
isEditable bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sellOut Null
final
timeStamp → DateTimeString
finalinherited

Methods

addEntryToDoc(BuildContext context) Future<FirestoreErrors?>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeFromDoc() Future<FirestoreErrors?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited