StateDoc class

Constructors

StateDoc.fromJson(RawMap _rawData)

Properties

boxes → IntQuntity
no setter
entries Iterable<Entry>
no setter
hashCode int
The hash code for this object.
no setterinherited
inventory Iterable<ItemQun>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
walletMoney → IntMoney
no setter

Methods

getBuyerEntries(String buyerNumber) Iterable<Entry>
getBuyInDuePayment(int sellerID) → IntMoney
getEntry(String? id) Entry?
getQuntityOf(String id) ItemQun
getSellerEntries(int sellerID) Iterable<Entry>
getSellOutDueBoxes(String buyerNumber) → IntQuntity
getSellOutDuePayment(String buyerNumber) → IntMoney
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inUse StateDoc?
no setter