B2bAuthUser class abstract

Inheritance

Constructors

B2bAuthUser(User user, Map<String, Object?> claims)

Properties

compneyIdInUse String?
no setter
compneyIDs Iterable<String>
no setter
hasExpiredPermission bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasOwnerPermission bool
no setter
hasWorkerPermission bool
no setter
isDev bool
finalinherited
phoneNumber String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user → User
finalinherited

Methods

hasCompney(String compneyID) bool
hasRoleOf([String? compneyID]) String
isExpired([String? compneyID]) bool
isOwner([String? compneyID]) bool
isWorker([String? compneyID]) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inUse B2bAuthUser?
no setter