Product class
Constructors
Properties
-
customerDiscount
→ Map<
String, IntMoney> -
final
- defaultBoughtRate → IntMoney
-
final
- defaultDiscount → IntMoney
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- isNew → bool
-
final
- name → String
-
final
- pckInBox → IntQuntity?
-
final
- rankOrderValue → int
-
final
- rate → IntMoney
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sellerRate
→ Map<
int, IntMoney> -
final
Methods
-
makeChanges(
{String? newName, int? newRate, int? newDefaultDiscount, Map< String, int> ? newCustomerDiscount, Map<int, int> ? newSellerRate, int? newDefaultBoughtRate, int? newRankOrderValue}) → Future<FirestoreErrors?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
) → Future< FirestoreErrors?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited