ProductDoc class
Constructors
- ProductDoc.fromJson(RawMap _rawData)
Properties
-
deletedItems
→ Iterable<
Product> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ Iterable<
Product> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getItem(
String? id) → Product? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- inUse → ProductDoc?
-
no setter