ItemSold class
Constructors
Properties
- amount → IntMoney
-
no setter
- discountApplyed → IntMoney
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
finalinherited
- isInv → bool
-
finalinherited
- pack → IntQuntity
-
finalinherited
- pckPerBox → IntQuntity
-
no setterinherited
- quntity → IntQuntity
-
finalinherited
- rate → IntMoney
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
packString(
) → String -
inherited
-
quntityString(
) → String -
inherited
-
toString(
{bool lead = true}) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → ItemQun -
inherited