SoldEntry class
Properties
- belongToDate → DateTimeString
-
no setterinherited
- buyerNumber → String
-
final
- buyIn → Null
-
final
- creator → String
-
finalinherited
- dueBoxes → DueBoxes
-
no setteroverride
- entryType → EntryType
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
finalinherited
- isEditable → bool
-
no setterinherited
-
itemSold
→ Iterable<
ItemSold> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sellOut → SellOut
-
no setteroverride
- timeStamp → DateTimeString
-
finalinherited
Methods
-
addEntryToDoc(
BuildContext context) → Future< FirestoreErrors?> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeFromDoc(
) → Future< FirestoreErrors?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited